@@ -27,10 +27,10 @@ from .native_monitor_curve_adapter import MonitorCurveTypes
 
 # Helpful functions
 from .convert import to_unit
-from .measurement import Measurement
+from .measurement import registry as unit_registry
 from .native_treatment_calculations import (median_treating_pressure, pumped_fluid_volume, total_proppant_mass)
 from .reference_origins import WellReferenceFrameXy
-from .unit_system import abbreviation
+from .unit_system import abbreviation, make_measurement
 
 # Only for training data
 from .configuration import training_data_path
