@@ -16,16 +16,18 @@
 #
 
 import uuid
+from typing import Callable, Union
 
 import deal
 import toolz.curried as toolz
 
-import orchid.validation
+from orchid import (
+    unit_system as units,
+)
 
 # noinspection PyUnresolvedReferences
 from System import Guid
 
-
 # These methods in this module are based on the StackOverflow post:
 # https://stackoverflow.com/questions/36580931/python-property-factory-or-descriptor-class-for-wrapping-an-external-library
 #
@@ -35,6 +37,23 @@ from System import Guid
 # attribute name at definition time (because `self` was only available at run-time).
 
 
+def constantly(x):
+    """
+    Creates a function that always returns the value, `x`.
+    Args:
+        x: The value to return
+
+    Returns:
+        Returns a function takes any arguments yet always returns `x`.
+    """
+
+    # noinspection PyUnusedLocal
+    def make_constantly(*args, **kwargs):
+        return toolz.identity(x)
+
+    return make_constantly
+
+
 def get_dot_net_property_value(attribute_name, dom_object):
     """
     Return the value of the DOM property whose name corresponds to `attribute_name`.
@@ -120,19 +139,23 @@ def as_uuid(guid: Guid):
 
 
 class DotNetAdapter:
-    @deal.pre(orchid.validation.arg_not_none)
-    def __init__(self, adaptee):
+    @deal.pre(lambda _self, adaptee, _net_project_callable=None: adaptee is not None)
+    def __init__(self, adaptee, net_project_callable: Callable = None):
         """
-        Construct an instance adapting a .NET IStage.
-        :param adaptee: The .NET DOM object to adapt.
+        Construct an instance adapting `adaptee` with access to the .NET `IProject` provided by `net_project_callable`.
+        Args:
+            adaptee: The .NET DOM object to adapt.
+            net_project_callable: A callable returning the .NET `IProject` instance.
         """
         self._adaptee = adaptee
+        self._net_project_callable = net_project_callable
 
     object_id = transformed_dom_property('object_id', 'The object ID of the adapted .NET DOM object.', as_uuid)
 
+    @property
     def dom_object(self):
         """
-        (PRIVATE) Determine the DOM object being adapted.
+        (PROTECTED) Determine the DOM object being adapted.
 
         This method is only intended to be used **INSIDE** the orchid package. It is **NOT** intended for
         external use.
@@ -141,3 +164,20 @@ class DotNetAdapter:
             The .NET DOM object being adapted.
         """
         return self._adaptee
+
+    @property
+    def maybe_project_units(self) -> Union[units.UsOilfield, units.Metric]:
+        """
+        (PROTECTED) Return the `UnitSystem` appropriate the .NET `IProject` of this instance.
+
+        Although by naming convention, this property is "public," the author intends it to be "protected";
+        that is, only called by classes derived from `DotNetAdapter` (and not necessarily all of those).
+
+        Returns:
+            The unit system, `units.UsOilfield` or `units.Metric`, for this instance. For some derived
+            classes, such as `BaseCurveAdapter`, the `IProject` cannot be determined. In those cases, I
+            return `None`.
+        """
+        return (units.as_unit_system(self._net_project_callable().ProjectUnits)
+                if self._net_project_callable
+                else None)
