@@ -96,7 +96,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
     """Adapts a .NET IStage to be more Pythonic."""
 
     def __init__(self, adaptee, calculations_factory=None):
-        super().__init__(adaptee)
+        super().__init__(adaptee, dna.constantly(adaptee.Well.Project))
         self.calculations_factory = Calculations.FractureDiagnosticsCalculationsFactory() \
             if not calculations_factory else calculations_factory
 
@@ -115,6 +115,30 @@ class NativeStageAdapter(dna.DotNetAdapter):
     start_time = dna.transformed_dom_property('start_time', 'The start time of the stage treatment', onq.as_datetime)
     stop_time = dna.transformed_dom_property('stop_time', 'The stop time of the stage treatment', onq.as_datetime)
 
+    @property
+    def isip(self) -> om.Quantity:
+        """
+        Return the instantaneous shut in pressure of this stage in project units.
+        """
+        return onq.as_measurement(self.maybe_project_units.PRESSURE, self.dom_object.Isip)
+
+    @property
+    def pnet(self) -> om.Quantity:
+        """
+        Return the net pressure of this stage in project units.
+
+        The net pressure of a stage is calculated by the formula:
+            pnet = isip + fluid-density * tvd - shmin (where tvd is the true vertical depth)
+        """
+        return onq.as_measurement(self.maybe_project_units.PRESSURE, self.dom_object.Pnet)
+
+    @property
+    def shmin(self) -> om.Quantity:
+        """
+        Return the minimum horizontal stress of this stage in project units.
+        """
+        return onq.as_measurement(self.maybe_project_units.PRESSURE, self.dom_object.Shmin)
+
     @staticmethod
     def _sampled_quantity_name_curve_map(sampled_quantity_name):
         candidates = toolz.pipe(ntc.TreatmentCurveTypes,
@@ -129,7 +153,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
         return candidates[0]
 
     def _center_location_depth(self, in_length_unit: Union[units.UsOilfield, units.Metric],
-                               depth_datum: origins.DepthDatum) -> om.Measurement:
+                               depth_datum: origins.DepthDatum) -> om.Quantity:
         """
         Return the depth of the stage center relative to the specified `depth_datum.`
 
@@ -158,7 +182,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
         """
 
         return subsurface_point_in_length_unit(depth_datum, xy_reference_frame, in_length_unit,
-                                               self._adaptee.GetStageLocationBottom)
+                                               self.dom_object.GetStageLocationBottom)
 
     def center_location(self, in_length_unit: Union[units.UsOilfield, units.Metric],
                         xy_reference_frame: origins.WellReferenceFrameXy,
@@ -176,10 +200,10 @@ class NativeStageAdapter(dna.DotNetAdapter):
             The `BaseSubsurfacePoint` of the stage center.
         """
         return subsurface_point_in_length_unit(depth_datum, xy_reference_frame, in_length_unit,
-                                               self._adaptee.GetStageLocationCenter)
+                                               self.dom_object.GetStageLocationCenter)
 
     def center_location_easting(self, in_length_unit: Union[units.UsOilfield, units.Metric],
-                                xy_well_reference_frame: origins.WellReferenceFrameXy) -> om.Measurement:
+                                xy_well_reference_frame: origins.WellReferenceFrameXy) -> om.Quantity:
         """
         Return the easting location of the stage center relative to the specified reference frame in the
         specified unit.
@@ -195,7 +219,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
         return result
 
     def center_location_northing(self, in_length_unit: Union[units.UsOilfield, units.Metric],
-                                 xy_well_reference_frame: origins.WellReferenceFrameXy) -> om.Measurement:
+                                 xy_well_reference_frame: origins.WellReferenceFrameXy) -> om.Quantity:
         """
         Return the northing location of the stage center in the `xy_well_reference_frame` in the specified unit.
 
@@ -210,7 +234,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
                                                 origins.DepthDatum.KELLY_BUSHING)
         return subsurface_point.y
 
-    def center_location_md(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Measurement:
+    def center_location_md(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Quantity:
         """
         Return the measured depth of the stage center in project units.
 
@@ -219,7 +243,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
         """
         return self._center_location_depth(in_length_unit, origins.DepthDatum.KELLY_BUSHING)
 
-    def center_location_tvdgl(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Measurement:
+    def center_location_tvdgl(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Quantity:
         """
         Returns the total vertical depth from ground level of the stage center in project units.
 
@@ -228,7 +252,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
         """
         return self._center_location_depth(in_length_unit, origins.DepthDatum.GROUND_LEVEL)
 
-    def center_location_tvdss(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Measurement:
+    def center_location_tvdss(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Quantity:
         """
         Returns the total vertical depth from sea level of the stage center in project units.
 
@@ -238,8 +262,8 @@ class NativeStageAdapter(dna.DotNetAdapter):
         return self._center_location_depth(in_length_unit, origins.DepthDatum.SEA_LEVEL)
 
     def center_location_xy(self, in_length_unit: Union[units.UsOilfield, units.Metric],
-                           xy_well_reference_frame: origins.WellReferenceFrameXy) -> Tuple[om.Measurement,
-                                                                                           om.Measurement]:
+                           xy_well_reference_frame: origins.WellReferenceFrameXy) -> Tuple[om.Quantity,
+                                                                                           om.Quantity]:
         """
         Return the easting-northing location of the stage center in the `xy_well_reference_frame` in project units.
 
@@ -271,31 +295,13 @@ class NativeStageAdapter(dna.DotNetAdapter):
         Returns:
             The `BaseSubsurfacePoint` of the stage cluster identified by `cluster_no`.
         """
-        stage_location_cluster_func = toolz.curry(self._adaptee.GetStageLocationCluster, cluster_no)
+        stage_location_cluster_func = toolz.curry(self.dom_object.GetStageLocationCluster, cluster_no)
         return subsurface_point_in_length_unit(depth_datum, xy_reference_frame, in_length_unit,
                                                stage_location_cluster_func)
 
     @deal.pre(validation.arg_is_acceptable_pressure_unit)
-    def isip_in_pressure_unit(self, target_unit: Union[units.UsOilfield, units.Metric]) -> om.Measurement:
-        net_isip = self._adaptee.Isip
-        net_isip_correct_units = onq.convert_net_quantity_to_different_unit(target_unit, net_isip)
-        return onq.as_pressure_measurement(net_isip_correct_units)
-
-    def md_top(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Measurement:
-        """
-        Return the measured depth of the top of this stage (closest to the well head / farthest from the toe)
-        in the specified unit.
-
-        Args:
-            in_length_unit: An unit of the requested resultant length unit.
-
-        Returns;
-         The measured depth of the stage top in the specified unit.
-        """
-        original = self._adaptee.MdTop
-        md_top_quantity = onq.convert_net_quantity_to_different_unit(in_length_unit, original)
-        result = onq.as_length_measurement(md_top_quantity)
-        return result
+    def isip_in_pressure_unit(self, target_unit: Union[units.UsOilfield, units.Metric]) -> om.Quantity:
+        return onq.as_measurement(target_unit, self.dom_object.Isip)
 
     def md_bottom(self, in_length_unit: Union[units.UsOilfield, units.Metric]):
         """
@@ -308,24 +314,30 @@ class NativeStageAdapter(dna.DotNetAdapter):
         Returns:
              The measured depth of the stage bottom in the specified unit.
         """
-        original = self._adaptee.MdBottom
-        md_top_quantity = onq.convert_net_quantity_to_different_unit(in_length_unit, original)
-        result = onq.as_length_measurement(md_top_quantity)
-        return result
+        return onq.as_measurement(in_length_unit, self.dom_object.MdBottom)
+
+    def md_top(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Quantity:
+        """
+        Return the measured depth of the top of this stage (closest to the well head / farthest from the toe)
+        in the specified unit.
+
+        Args:
+            in_length_unit: An unit of the requested resultant length unit.
+
+        Returns;
+         The measured depth of the stage top in the specified unit.
+        """
+        return onq.as_measurement(in_length_unit, self.dom_object.MdTop)
 
     @deal.pre(validation.arg_is_acceptable_pressure_unit)
-    def pnet_in_pressure_unit(self, target_unit: Union[units.UsOilfield, units.Metric]) -> om.Measurement:
-        net_pnet = self._adaptee.Pnet
-        net_pnet_correct_units = onq.convert_net_quantity_to_different_unit(target_unit, net_pnet)
-        return onq.as_pressure_measurement(net_pnet_correct_units)
+    def pnet_in_pressure_unit(self, target_unit: Union[units.UsOilfield, units.Metric]) -> om.Quantity:
+        return onq.as_measurement(target_unit, self.dom_object.Pnet)
 
     @deal.pre(validation.arg_is_acceptable_pressure_unit)
-    def shmin_in_pressure_unit(self, target_unit: Union[units.UsOilfield, units.Metric]) -> om.Measurement:
-        net_shmin = self._adaptee.Shmin
-        net_shmin_correct_units = onq.convert_net_quantity_to_different_unit(target_unit, net_shmin)
-        return onq.as_pressure_measurement(net_shmin_correct_units)
+    def shmin_in_pressure_unit(self, target_unit: Union[units.UsOilfield, units.Metric]) -> om.Quantity:
+        return onq.as_measurement(target_unit, self.dom_object.Shmin)
 
-    def stage_length(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Measurement:
+    def stage_length(self, in_length_unit: Union[units.UsOilfield, units.Metric]) -> om.Quantity:
         """
         Return the stage length in the specified unit.
 
@@ -335,10 +347,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
         Returns:
             The Measurement of the length of this stage.
         """
-        length_magnitude = \
-            self.md_bottom(in_length_unit).magnitude - self.md_top(in_length_unit).magnitude
-        result = om.make_measurement(in_length_unit, length_magnitude)
-        return result
+        return self.md_bottom(in_length_unit) - self.md_top(in_length_unit)
 
     def top_location(self, in_length_unit: Union[units.UsOilfield, units.Metric],
                      xy_reference_frame: origins.WellReferenceFrameXy,
@@ -356,7 +365,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
             The `BaseSubsurfacePoint` of the stage top.
         """
         return subsurface_point_in_length_unit(depth_datum, xy_reference_frame, in_length_unit,
-                                               self._adaptee.GetStageLocationTop)
+                                               self.dom_object.GetStageLocationTop)
 
     def treatment_curves(self):
         """
@@ -371,7 +380,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
         Returns:
             The dictionary containing the available treatment curves.
         """
-        if not self._adaptee.TreatmentCurves.Items:
+        if not self.dom_object.TreatmentCurves.Items:
             return {}
 
         def add_curve(so_far, treatment_curve):
@@ -379,7 +388,7 @@ class NativeStageAdapter(dna.DotNetAdapter):
             treatment_curve_map = {curve_name: treatment_curve}
             return toolz.merge(treatment_curve_map, so_far)
 
-        result = toolz.pipe(self._adaptee.TreatmentCurves.Items,  # start with .NET treatment curves
+        result = toolz.pipe(self.dom_object.TreatmentCurves.Items,  # start with .NET treatment curves
                             toolz.map(ntc.NativeTreatmentCurveAdapter),  # wrap them in a facade
                             # Transform the map to a dictionary keyed by the sampled quantity name
                             lambda cs: toolz.reduce(add_curve, cs, {}))
