@@ -17,10 +17,11 @@ import abc
 from typing import Union
 
 
-from orchid import (dot_net_dom_access as dna,
-                    net_quantity as onq,
-                    physical_quantity as opq,
-                    unit_system as units)
+from orchid import (
+    dot_net_dom_access as dna,
+    net_quantity as onq,
+    unit_system as units,
+)
 
 import toolz.curried as toolz
 
@@ -67,24 +68,28 @@ class SubsurfacePointUsingLengthUnit(BaseSubsurfacePoint):
             target_length_unit: The target unit for all lengths.
         """
         super().__init__(adaptee)
-        self._length_converter_func = onq.convert_net_quantity_to_different_unit(target_length_unit)
-        self._as_length_measurement_func = onq.as_measurement(opq.PhysicalQuantity.LENGTH)
+        self._as_length_measurement_func = onq.as_measurement(target_length_unit)
 
     @property
     def x(self):
         """The x-coordinate of this point."""
-        return onq.as_length_measurement(self._length_converter_func(self._adaptee.X))
+        return self._as_length_measurement_func(self.dom_object.X)
 
     @property
     def y(self):
         """The y-coordinate of this point."""
-        return onq.as_length_measurement(self._length_converter_func(self._adaptee.Y))
+        return self._as_length_measurement_func(self.dom_object.Y)
 
     @property
     def depth(self):
         """The depth of this point."""
-        result = onq.as_length_measurement(self._length_converter_func(self._adaptee.Depth))
-        return result
+        return self._as_length_measurement_func(self.dom_object.Depth)
+
+
+@toolz.curry
+def make_subsurface_point_using_length_unit(target_unit: Union[units.UsOilfield, units.Metric],
+                                            net_subsurface_point: ISubsurfacePoint) -> SubsurfacePointUsingLengthUnit:
+    return SubsurfacePointUsingLengthUnit(net_subsurface_point, target_unit)
 
 
 class SubsurfacePoint(BaseSubsurfacePoint):
@@ -105,4 +110,4 @@ class SubsurfacePoint(BaseSubsurfacePoint):
             A `SubsurfacePoint` that returns all lengths `as_length_unit`.
 
         """
-        return SubsurfacePointUsingLengthUnit(self._adaptee, as_length_unit)
+        return SubsurfacePointUsingLengthUnit(self.dom_object, as_length_unit)
