@@ -15,7 +15,8 @@
 # This file is part of Orchid and related technologies.
 #
 
-from typing import List, Tuple, Iterable
+from collections import namedtuple
+from typing import List, Tuple, Iterable, Dict
 
 import deal
 import toolz.curried as toolz
@@ -23,7 +24,9 @@ import toolz.curried as toolz
 from orchid import (
     dot_net_dom_access as dna,
     native_well_adapter as nwa,
+    native_monitor_adapter as nma,
     native_monitor_curve_adapter as mca,
+    net_quantity as onq,
     unit_system as units,
 )
 from orchid.project_loader import ProjectLoader
@@ -33,7 +36,13 @@ from Orchid.FractureDiagnostics import IWell, UnitSystem
 # noinspection PyUnresolvedReferences
 import UnitsNet
 
-from orchid.unit_system import as_unit_system
+
+ProjectBounds = namedtuple('ProjectBounds', [
+    'min_x', 'max_x',
+    'min_y', 'max_y',
+    'min_depth', 'max_depth',
+])
+SurfacePoint = namedtuple('SurfacePoint', ['x', 'y'])
 
 
 class Project(dna.DotNetAdapter):
@@ -51,11 +60,17 @@ class Project(dna.DotNetAdapter):
         self._are_well_loaded = False
         self._wells = []
 
+    azimuth = dna.transformed_dom_property('azimuth', 'The azimuth of the project.', onq.as_angle_measurement)
     name = dna.dom_property('name', 'The name of this project.')
-    project_units = dna.transformed_dom_property('project_units', 'The project unit system.', as_unit_system)
+    project_units = dna.transformed_dom_property('project_units', 'The project unit system.', units.as_unit_system)
     wells = dna.transformed_dom_property_iterator('wells', 'An iterator of all the wells in this project.',
                                                   nwa.NativeWellAdapter)
 
+    @property
+    def fluid_density(self):
+        """The fluid density of the project in project units."""
+        return onq.as_measurement(self.project_units.DENSITY, self.dom_object.FluidDensity)
+
     def default_well_colors(self) -> List[Tuple[float, float, float]]:
         """
         Calculate the default well colors for this project.
@@ -66,17 +81,52 @@ class Project(dna.DotNetAdapter):
 
     def monitor_curves(self) -> Iterable[mca.NativeMonitorCurveAdapter]:
         """
-            Return a sequence of well time series for this project.
+        Return a sequence of well time series for this project.
+
         Returns:
             An iterable of well time series.
         """
         native_time_series_list_items = self._project_loader.native_project().WellTimeSeriesList.Items
         if len(native_time_series_list_items) > 0:
-            return toolz.map(mca.NativeMonitorCurveAdapter,
-                             self._project_loader.native_project().WellTimeSeriesList.Items)
+            return toolz.pipe(native_time_series_list_items,
+                              toolz.map(mca.NativeMonitorCurveAdapter),
+                              list)
         else:
             return []
 
+    def monitors(self) -> Dict[str, nma.NativeMonitorAdapter]:
+        """
+        Return a dictionary of monitors for this project indexed by the monitor display name.
+
+        Returns:
+            An dictionary of `NativeMonitorAdapter`s indexed by the display name of each monitor.
+        """
+        def collect_monitors(so_far, monitor):
+            return toolz.assoc(so_far, monitor.DisplayName, monitor)
+
+        result = toolz.pipe(self._project_loader.native_project().Monitors.Items,
+                            lambda ms: toolz.reduce(collect_monitors, ms, {}),
+                            toolz.valmap(lambda m: nma.NativeMonitorAdapter(m)))
+        return result
+
+    def project_bounds(self) -> ProjectBounds:
+        result = toolz.pipe(self.dom_object.GetProjectBounds(),
+                            toolz.map(onq.as_measurement(self.project_units.LENGTH)),
+                            list,
+                            lambda ls: ProjectBounds(*ls))
+        return result
+
+    def project_center(self) -> SurfacePoint:
+        """
+        Return the location of the project center on the surface measured in project units.
+        """
+        net_center = self.dom_object.GetProjectCenter()
+        result = toolz.pipe(net_center,
+                            toolz.map(onq.as_measurement(self.project_units.LENGTH)),
+                            list,
+                            lambda ls: SurfacePoint(ls[0], ls[1]))
+        return result
+
     def proppant_concentration_mass_unit(self):
         if self.project_units == units.UsOilfield:
             return units.UsOilfield.MASS
